==> ChillBoss-0.2.0.tar.gz: ChillBoss-0.2.0/README.md <==
# ChillBoss

[![Downloads](https://static.pepy.tech/personalized-badge/chillboss?period=total&units=international_system&left_color=blue&right_color=green&left_text=Total%20Downloads)](https://pepy.tech/project/chillboss)
[![Monthly_Downloads](https://static.pepy.tech/personalized-badge/chillboss?period=month&units=international_system&left_color=blue&right_color=green&left_text=Downloads/Month)](https://pepy.tech/project/chillboss)
[![Weekly_Downloads](https://static.pepy.tech/personalized-badge/chillboss?period=week&units=international_system&left_color=blue&right_color=green&left_text=Downloads/Week)](https://pepy.tech/project/chillboss)
[![Hygiene](https://github.com/NaveenKumarReddy8/ChillBoss/actions/workflows/main.yml/badge.svg)](https://github.com/NaveenKumarReddy8/ChillBoss/actions/workflows/main.yml)
[![chillboss](https://snyk.io/advisor/python/chillboss/badge.svg)](https://snyk.io/advisor/python/chillboss)
[![PyPI version fury.io](https://badge.fury.io/py/chillboss.svg)](https://pypi.python.org/pypi/chillboss/)

Version: 0.2.0

ChillBoss keeps your mouse moving to keep your status alive 😎.

Homepage: https://naveenkumarreddy8.github.io/ChillBoss/

Installation:

ChillBoss is published on PyPI: https://pypi.org/project/chillboss/ 

```shell
pip install chillboss
```

![ChillBoss Installation](https://media.giphy.com/media/gzccwAinTwGWRdkyu8/giphy.gif)

Usage:

```shell
python -m chillboss
```

Command line argument accepted:

* --movement: `random` and `square` movements are accepted. Default set to `random`.
* --length: Accepted for `square` type of movement. Default set to `None`.
* --sleeptime: Time to be taken till next movement. Default set to 30 seconds.
* --motiontime: Time consumption of pointer to move from present coordinates to the next coordinates. Default set to 0
  seconds.
* --verbose: Flag argument when given as input, sets the log level to Debug, else Warning.

![ChillBoss Usage](https://media.giphy.com/media/DsYnp69mhQeKoAxu7x/giphy.gif)


Made with love ❤️

==> ChillBoss-0.4.0.tar.gz: ChillBoss-0.4.0/README.md <==
# ChillBoss

[![Downloads](https://static.pepy.tech/personalized-badge/chillboss?period=total&units=international_system&left_color=blue&right_color=green&left_text=Total%20Downloads)](https://pepy.tech/project/chillboss)
[![Monthly_Downloads](https://static.pepy.tech/personalized-badge/chillboss?period=month&units=international_system&left_color=blue&right_color=green&left_text=Downloads/Month)](https://pepy.tech/project/chillboss)
[![Weekly_Downloads](https://static.pepy.tech/personalized-badge/chillboss?period=week&units=international_system&left_color=blue&right_color=green&left_text=Downloads/Week)](https://pepy.tech/project/chillboss)
[![Hygiene](https://github.com/NaveenKumarReddy8/ChillBoss/actions/workflows/main.yml/badge.svg)](https://github.com/NaveenKumarReddy8/ChillBoss/actions/workflows/main.yml)
[![chillboss](https://snyk.io/advisor/python/chillboss/badge.svg)](https://snyk.io/advisor/python/chillboss)
[![PyPI version fury.io](https://badge.fury.io/py/chillboss.svg)](https://pypi.python.org/pypi/chillboss/)

Version: 0.4.0

ChillBoss keeps your mouse moving to keep your status alive 😎.

Homepage: https://naveenkumarreddy8.github.io/ChillBoss/

Installation:

ChillBoss is published on PyPI: https://pypi.org/project/chillboss/ 

```shell
pip install chillboss
```

---

**NOTE**

On Linux you may need to install python3-tk python3-dev

```
sudo apt-get install python3-tk python3-dev
```

---


![ChillBoss Installation](https://media.giphy.com/media/aDoezJuCfRnEf4KErq/source.gif)

Usage:

```shell
chillboss [options]
```

Command line argument accepted:

* -m, --movement: `random` and `square` movements are accepted. Default set to `random`.
* -l, --length: Accepted for `square` type of movement. Default set to `None`.
* -s, --sleeptime: Time to be taken till next movement. Default set to 30 seconds.
* -mt, --motiontime: Time consumption of pointer to move from present coordinates to the next coordinates. Default set to 0
  seconds.
* -v, --verbose: Flag argument when given as input, sets the log level to Debug, else Warning.

![ChillBoss Usage](https://media.giphy.com/media/TrlvEhASiYMqNZ7Gy9/source.gif)


Made with love ❤️
